@@ -5,4 +5,4 @@ import click_completion
 click_completion.init()
 
 # Import to populate sub commands
-from aiida_optimade.cli import cmd_init, cmd_run  # noqa: E402,F401
+from aiida_optimade.cli import cmd_calc, cmd_init, cmd_run  # noqa: E402,F401
